@@ -22,13 +22,10 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#ifndef GSPDFIMVIEW_H
-#define GSPDFIMVIEW_H
+#import <Foundation/Foundation.h>
+#import <AppKit/NSImageView.h>
+#import "GSPdfDocument.h"
 
-#include <Foundation/Foundation.h>
-#include <AppKit/NSView.h>
-
-@class GSPdfDocument;
 
 @interface GSPdfImView : NSImageView
 {
@@ -39,5 +36,3 @@
 
 @end
 
-#endif // GSPDFIMVIEW_H
-
